@@ -90,10 +90,7 @@ def get_protocol_parameters(protocol_hash: str) -> Dict[str, Any]:
             'minimal_block_delay': '0',
             'liquidity_baking_subsidy': '2500000',
             'liquidity_baking_sunset_level': 2032928.0,
-            'liquidity_baking_escape_ema_threshold': 1000000.0
+            'liquidity_baking_escape_ema_threshold': 1000000.0,
         }
     else:
-        return {
-            **sandbox_params,
-            'test_chain_duration': '1966080'
-        }
+        return {**sandbox_params, 'test_chain_duration': '1966080'}
